---
label: KLUSTA
dockerfile: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/klusta/container/Dockerfile
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/klusta/klusta.py
notes:
website:
source_code:
authors:
processor_name: Klusta
doi:
---
_
# KLUSTAKWIK

## Description

## References

